=== modified file 'drizzled/create_field.cc'
--- drizzled/create_field.cc	2010-12-18 00:43:02 +0000
+++ drizzled/create_field.cc	2010-12-20 19:20:57 +0000
@@ -47,6 +47,8 @@
 #include "drizzled/temporal.h"
 #include "drizzled/item/string.h"
 
+#include "drizzled/display.h"
+
 #include <algorithm>
 
 using namespace std;
@@ -394,4 +396,40 @@
   return false; /* success */
 }
 
+std::ostream& operator<<(std::ostream& output, const CreateField &field)
+{
+  output << "CreateField:(";
+  output <<  field.field_name;
+  output << ", ";
+  output << drizzled::display::type(field.type());
+  output << ", { ";
+
+  if (field.flags & NOT_NULL_FLAG)
+    output << " NOT_NULL";
+
+  if (field.flags & PRI_KEY_FLAG)
+    output << ", PRIMARY KEY";
+
+  if (field.flags & UNIQUE_KEY_FLAG)
+    output << ", UNIQUE KEY";
+
+  if (field.flags & MULTIPLE_KEY_FLAG)
+    output << ", MULTIPLE KEY";
+
+  if (field.flags & BLOB_FLAG)
+    output << ", BLOB";
+
+  if (field.flags & UNSIGNED_FLAG)
+    output << ", UNSIGNED";
+
+  if (field.flags & BINARY_FLAG)
+    output << ", BINARY";
+  output << "}, ";
+  if (field.field)
+    output << *field.field;
+  output << ")";
+
+  return output;  // for multiple << operators.
+}
+
 } /* namespace drizzled */

=== modified file 'drizzled/create_field.h'
--- drizzled/create_field.h	2010-05-29 01:13:40 +0000
+++ drizzled/create_field.h	2010-12-20 19:20:57 +0000
@@ -43,6 +43,12 @@
   LEX_STRING comment; /**< A comment for this field */
   Item *def; /**< Default value for the new field */
   enum enum_field_types sql_type; /**< The data type of the new field */
+
+  enum_field_types type() const
+  {
+    return sql_type;
+  }
+
   /**
    * At various stages in execution this can be length of field in bytes or
    * max number of characters.
@@ -126,6 +132,8 @@
             enum column_format_type column_format);
 };
 
+std::ostream& operator<<(std::ostream& output, const CreateField &field);
+
 } /* namespace drizzled */
 
 #endif /* DRIZZLED_CREATE_FIELD_H */

=== modified file 'drizzled/field.cc'
--- drizzled/field.cc	2010-12-18 00:43:02 +0000
+++ drizzled/field.cc	2010-12-20 19:20:57 +0000
@@ -1084,6 +1084,29 @@
   output <<  field.field_name;
   output << ", ";
   output << drizzled::display::type(field.real_type());
+  output << ", { ";
+
+  if (field.flags & NOT_NULL_FLAG)
+    output << " NOT_NULL";
+
+  if (field.flags & PRI_KEY_FLAG)
+    output << ", PRIMARY KEY";
+
+  if (field.flags & UNIQUE_KEY_FLAG)
+    output << ", UNIQUE KEY";
+
+  if (field.flags & MULTIPLE_KEY_FLAG)
+    output << ", MULTIPLE KEY";
+
+  if (field.flags & BLOB_FLAG)
+    output << ", BLOB";
+
+  if (field.flags & UNSIGNED_FLAG)
+    output << ", UNSIGNED";
+
+  if (field.flags & BINARY_FLAG)
+    output << ", BINARY";
+  output << "}, ";
   output << ")";
 
   return output;  // for multiple << operators.

=== modified file 'drizzled/field/int64.cc'
--- drizzled/field/int64.cc	2010-12-20 10:21:10 +0000
+++ drizzled/field/int64.cc	2010-12-20 19:20:57 +0000
@@ -110,13 +110,11 @@
   (void)arg;
 
   ASSERT_COLUMN_MARKED_FOR_WRITE;
-#if 0
   if (arg and (nr < 0)) // Only a partial fix for overflow
   {
     set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN, ER_WARN_DATA_OUT_OF_RANGE, 1);
     error= 1;
   }
-#endif
 
   int64_tstore(ptr,nr);
 

=== modified file 'drizzled/field/size.cc'
--- drizzled/field/size.cc	2010-12-20 10:21:10 +0000
+++ drizzled/field/size.cc	2010-12-20 19:20:57 +0000
@@ -42,6 +42,38 @@
   Field type Size int (8 bytes)
  ****************************************************************************/
 
+Size::Size(unsigned char *ptr_arg, uint32_t len_arg,
+           unsigned char *null_ptr_arg,
+           unsigned char null_bit_arg,
+           enum utype unireg_check_arg,
+           const char *field_name_arg) :
+  Field_num(ptr_arg,
+            len_arg,
+            null_ptr_arg,
+            null_bit_arg,
+            unireg_check_arg,
+            field_name_arg,
+            0, false, true)
+{
+  flags|= UNSIGNED_FLAG;
+}
+
+Size::Size(uint32_t len_arg,bool maybe_null_arg,
+           const char *field_name_arg,
+           bool unsigned_arg) :
+  Field_num((unsigned char*) 0,
+            len_arg, maybe_null_arg ? (unsigned char*) "": 0,
+            0,
+            NONE,
+            field_name_arg,
+            0,
+            0,
+            unsigned_arg)
+{
+  flags|= UNSIGNED_FLAG;
+  assert(unsigned_arg);
+}
+
 int Size::store(const char *from,uint32_t len, const CHARSET_INFO * const cs)
 {
   int error= 0;

=== modified file 'drizzled/field/size.h'
--- drizzled/field/size.h	2010-12-20 10:21:10 +0000
+++ drizzled/field/size.h	2010-12-20 19:20:57 +0000
@@ -42,31 +42,11 @@
         unsigned char *null_ptr_arg,
         unsigned char null_bit_arg,
         enum utype unireg_check_arg,
-        const char *field_name_arg) :
-    Field_num(ptr_arg,
-              len_arg,
-              null_ptr_arg,
-              null_bit_arg,
-              unireg_check_arg,
-              field_name_arg,
-              0, false, true)
-  {
-  }
+        const char *field_name_arg);
 
   Size(uint32_t len_arg,bool maybe_null_arg,
         const char *field_name_arg,
-        bool unsigned_arg) :
-    Field_num((unsigned char*) 0,
-              len_arg, maybe_null_arg ? (unsigned char*) "": 0,
-              0,
-              NONE,
-              field_name_arg,
-              0,
-              0,
-              unsigned_arg)
-    {
-      assert(unsigned_arg);
-    }
+        bool unsigned_arg);
 
   enum Item_result result_type () const { return INT_RESULT; }
   enum_field_types type() const { return DRIZZLE_TYPE_LONGLONG;}

=== modified file 'drizzled/plugin/table_function.cc'
--- drizzled/plugin/table_function.cc	2010-12-12 20:55:48 +0000
+++ drizzled/plugin/table_function.cc	2010-12-20 19:20:57 +0000
@@ -141,8 +141,12 @@
       string_field_options->set_collation_id(my_charset_bin.number);
     }
     break;
-  case TableFunction::NUMBER: // Currently NUMBER always has a value
-    field->set_type(drizzled::message::Table::Field::BIGINT);
+  case TableFunction::NUMBER:
+    field->set_type(drizzled::message::Table::Field::BIGINT);
+    break;
+  case TableFunction::SIZE:
+    field->set_type(drizzled::message::Table::Field::BIGINT);
+    field_constraints->set_is_unsigned(true);
     break;
   }
 }

=== modified file 'drizzled/plugin/table_function.h'
--- drizzled/plugin/table_function.h	2010-10-24 01:20:11 +0000
+++ drizzled/plugin/table_function.h	2010-12-20 19:20:57 +0000
@@ -99,7 +99,8 @@
     BOOLEAN,
     NUMBER,
     STRING,
-    VARBINARY
+    VARBINARY,
+    SIZE
   };
 
   class Generator 

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2010-12-11 17:34:45 +0000
+++ drizzled/statement/alter_table.cc	2010-12-20 19:20:57 +0000
@@ -337,11 +337,13 @@
       new_create_list.push_back(def);
       alter_it.rewind(); /* Change default if ALTER */
       AlterColumn *alter;
+
       while ((alter= alter_it++))
       {
         if (! my_strcasecmp(system_charset_info,field->field_name, alter->name))
           break;
       }
+
       if (alter)
       {
         if (def->sql_type == DRIZZLE_TYPE_BLOB)
@@ -349,6 +351,7 @@
           my_error(ER_BLOB_CANT_HAVE_DEFAULT, MYF(0), def->change);
           return true;
         }
+
         if ((def->def= alter->def))
         {
           /* Use new default */
@@ -620,6 +623,7 @@
              alter_info->drop_list.head()->name);
     return true;
   }
+
   if (alter_info->alter_list.elements)
   {
     my_error(ER_CANT_DROP_FIELD_OR_KEY,

=== modified file 'drizzled/table_proto_write.cc'
--- drizzled/table_proto_write.cc	2010-12-20 10:21:10 +0000
+++ drizzled/table_proto_write.cc	2010-12-20 19:20:57 +0000
@@ -83,10 +83,18 @@
 
       if (field_arg->flags & NOT_NULL_FLAG)
       {
-        message::Table::Field::FieldConstraints *constraints;
+        attribute->mutable_constraints()->set_is_nullable(false);
+      }
+      else
+      {
+        attribute->mutable_constraints()->set_is_nullable(true);
+      }
 
-        constraints= attribute->mutable_constraints();
-        constraints->set_is_nullable(false);
+      if (field_arg->flags & UNSIGNED_FLAG and 
+          (field_arg->sql_type == DRIZZLE_TYPE_LONGLONG or field_arg->sql_type == DRIZZLE_TYPE_LONG))
+      {
+        field_arg->sql_type= DRIZZLE_TYPE_LONGLONG;
+        attribute->mutable_constraints()->set_is_unsigned(true);
       }
 
       attribute->set_name(field_arg->field_name);
@@ -203,7 +211,6 @@
       break;
     }
 
-    std::cerr << " Look at " << message::type(use_existing_fields) << " " << message::type(parser_type) << " " << message::type(attribute->type()) << "\n";
     assert (!use_existing_fields || parser_type == attribute->type());
 
 #ifdef NOTDONE

=== modified file 'plugin/session_dictionary/processlist.cc'
--- plugin/session_dictionary/processlist.cc	2010-12-16 21:20:57 +0000
+++ plugin/session_dictionary/processlist.cc	2010-12-20 19:20:57 +0000
@@ -43,7 +43,7 @@
   add_field("HOST", NI_MAXHOST);
   add_field("DB", plugin::TableFunction::STRING, MAXIMUM_IDENTIFIER_LENGTH, true);
   add_field("COMMAND", 16);
-  add_field("TIME", plugin::TableFunction::NUMBER, 0, false);
+  add_field("TIME", plugin::TableFunction::SIZE, 0, false);
   add_field("STATE", plugin::TableFunction::STRING, 256, true);
   add_field("INFO", plugin::TableFunction::STRING, PROCESS_LIST_WIDTH, true);
   add_field("HAS_GLOBAL_LOCK", plugin::TableFunction::BOOLEAN);

=== modified file 'plugin/session_dictionary/tests/r/data_dictionary.result'
--- plugin/session_dictionary/tests/r/data_dictionary.result	2010-12-12 22:52:20 +0000
+++ plugin/session_dictionary/tests/r/data_dictionary.result	2010-12-20 19:20:57 +0000
@@ -7,7 +7,7 @@
   `HOST` VARCHAR(1025) NOT NULL,
   `DB` VARCHAR(256) DEFAULT NULL,
   `COMMAND` VARCHAR(16) NOT NULL,
-  `TIME` BIGINT NOT NULL,
+  `TIME` BIGINT UNSIGNED NOT NULL,
   `STATE` VARCHAR(256) DEFAULT NULL,
   `INFO` VARCHAR(100) DEFAULT NULL,
   `HAS_GLOBAL_LOCK` VARCHAR(5) NOT NULL

=== modified file 'plugin/transaction_log/tests/r/transaction_log_data_type.result'
--- plugin/transaction_log/tests/r/transaction_log_data_type.result	2010-10-28 21:31:13 +0000
+++ plugin/transaction_log/tests/r/transaction_log_data_type.result	2010-12-20 19:20:57 +0000
@@ -612,15 +612,16 @@
 Testing MAX+1 BIGINT
 NOTE: Bug#316221 - 2**63 incorrectly inserted into bigint
 INSERT INTO t1 (b) VALUES(9223372036854775808);
+ERROR 22003: Out of range value for column 'b' at row 1
 Check transaction_log_entries
 SELECT COUNT(*) FROM DATA_DICTIONARY.TRANSACTION_LOG_ENTRIES;
 COUNT(*)
-5
+4
 
 Check transaction_log_transactions
 SELECT COUNT(*) FROM DATA_DICTIONARY.TRANSACTION_LOG_TRANSACTIONS;
 COUNT(*)
-5
+4
 Check transaction log contents
 SELECT PRINT_TRANSACTION_MESSAGE('transaction.log',(select max(entry_offset) from DATA_DICTIONARY.TRANSACTION_LOG_TRANSACTIONS));
 PRINT_TRANSACTION_MESSAGE('transaction.log',(select max(entry_offset) from DATA_DICTIONARY.TRANSACTION_LOG_TRANSACTIONS))
@@ -652,8 +653,8 @@
     segment_id: 1
     end_segment: true
     record {
-      insert_value: "3"
-      insert_value: "-9223372036854775808"
+      insert_value: "2"
+      insert_value: "9223372036854775807"
       is_null: false
       is_null: false
     }
@@ -667,12 +668,12 @@
 Check transaction_log_entries
 SELECT COUNT(*) FROM DATA_DICTIONARY.TRANSACTION_LOG_ENTRIES;
 COUNT(*)
-6
+5
 
 Check transaction_log_transactions
 SELECT COUNT(*) FROM DATA_DICTIONARY.TRANSACTION_LOG_TRANSACTIONS;
 COUNT(*)
-6
+5
 Check transaction log contents
 SELECT PRINT_TRANSACTION_MESSAGE('transaction.log',(select max(entry_offset) from DATA_DICTIONARY.TRANSACTION_LOG_TRANSACTIONS));
 PRINT_TRANSACTION_MESSAGE('transaction.log',(select max(entry_offset) from DATA_DICTIONARY.TRANSACTION_LOG_TRANSACTIONS))
@@ -704,7 +705,7 @@
     segment_id: 1
     end_segment: true
     record {
-      insert_value: "4"
+      insert_value: "3"
       insert_value: ""
       is_null: false
       is_null: true
@@ -720,12 +721,12 @@
 Check transaction_log_entries
 SELECT COUNT(*) FROM DATA_DICTIONARY.TRANSACTION_LOG_ENTRIES;
 COUNT(*)
-6
+5
 
 Check transaction_log_transactions
 SELECT COUNT(*) FROM DATA_DICTIONARY.TRANSACTION_LOG_TRANSACTIONS;
 COUNT(*)
-6
+5
 Check transaction log contents
 SELECT PRINT_TRANSACTION_MESSAGE('transaction.log',(select max(entry_offset) from DATA_DICTIONARY.TRANSACTION_LOG_TRANSACTIONS));
 PRINT_TRANSACTION_MESSAGE('transaction.log',(select max(entry_offset) from DATA_DICTIONARY.TRANSACTION_LOG_TRANSACTIONS))
@@ -757,7 +758,7 @@
     segment_id: 1
     end_segment: true
     record {
-      insert_value: "4"
+      insert_value: "3"
       insert_value: ""
       is_null: false
       is_null: true
@@ -773,12 +774,12 @@
 Check transaction_log_entries
 SELECT COUNT(*) FROM DATA_DICTIONARY.TRANSACTION_LOG_ENTRIES;
 COUNT(*)
-6
+5
 
 Check transaction_log_transactions
 SELECT COUNT(*) FROM DATA_DICTIONARY.TRANSACTION_LOG_TRANSACTIONS;
 COUNT(*)
-6
+5
 Check transaction log contents
 SELECT PRINT_TRANSACTION_MESSAGE('transaction.log',(select max(entry_offset) from DATA_DICTIONARY.TRANSACTION_LOG_TRANSACTIONS));
 PRINT_TRANSACTION_MESSAGE('transaction.log',(select max(entry_offset) from DATA_DICTIONARY.TRANSACTION_LOG_TRANSACTIONS))
@@ -810,7 +811,7 @@
     segment_id: 1
     end_segment: true
     record {
-      insert_value: "4"
+      insert_value: "3"
       insert_value: ""
       is_null: false
       is_null: true

=== modified file 'plugin/transaction_log/tests/t/transaction_log_data_type.test'
--- plugin/transaction_log/tests/t/transaction_log_data_type.test	2010-10-28 21:31:13 +0000
+++ plugin/transaction_log/tests/t/transaction_log_data_type.test	2010-12-20 19:20:57 +0000
@@ -105,7 +105,7 @@
 
 --echo Testing MAX+1 BIGINT
 --echo NOTE: Bug#316221 - 2**63 incorrectly inserted into bigint
-#--ERROR ER_WARN_DATA_OUT_OF_RANGE
+--ERROR ER_WARN_DATA_OUT_OF_RANGE
 INSERT INTO t1 (b) VALUES(9223372036854775808);
 --source ../plugin/transaction_log/tests/t/check_transaction_log.inc
 --echo

=== modified file 'tests/r/bigint.result'
--- tests/r/bigint.result	2010-10-14 18:58:48 +0000
+++ tests/r/bigint.result	2010-12-20 19:20:57 +0000
@@ -23,35 +23,38 @@
 select -1,-11,-101,-1001,-10001,-100001,-1000001,-10000001,-100000001,-1000000001,-10000000001,-100000000001,-1000000000001,-10000000000001,-100000000000001,-1000000000000001,-10000000000000001,-100000000000000001,-1000000000000000001,-10000000000000000001;
 -1	-11	-101	-1001	-10001	-100001	-1000001	-10000001	-100000001	-1000000001	-10000000001	-100000000001	-1000000000001	-10000000000001	-100000000000001	-1000000000000001	-10000000000000001	-100000000000000001	-1000000000000000001	-10000000000000000001
 -1	-11	-101	-1001	-10001	-100001	-1000001	-10000001	-100000001	-1000000001	-10000000001	-100000000001	-1000000000001	-10000000000001	-100000000000001	-1000000000000001	-10000000000000001	-100000000000000001	-1000000000000000001	-10000000000000000001
-create table t1 (a bigint not null, primary key(a));
+create table t1 (a bigint unsigned not null, primary key(a));
 insert into t1 values (9223372036854775808);
 insert into t1 values (0x7000000000000000);
 select * from t1;
 a
+8070450532247928832
 -9223372036854775808
-8070450532247928832
 select * from t1 where a=18446744073709551615;
 a
 delete from t1 where a=18446744073709551615;
 select * from t1;
 a
+8070450532247928832
 -9223372036854775808
-8070450532247928832
 drop table t1;
-create table t1 ( a int not null default 1, big bigint );
+create table t1 ( a int not null default 1, big bigint unsigned);
 insert into t1 (big) values (-1),(9223372036854775808),(9223372036854775807),(9223372036854775808);
+ERROR 22003: Out of range value for column 'big' at row 1
+insert into t1 (big) values (-1);
+ERROR 22003: Out of range value for column 'big' at row 1
+insert into t1 (big) values (9223372036854775808),(9223372036854775807),(9223372036854775808);
 select * from t1;
 a	big
-1	-1
 1	-9223372036854775808
 1	9223372036854775807
 1	-9223372036854775808
 select min(big),max(big),max(big)-1 from t1;
 min(big)	max(big)	max(big)-1
--9223372036854775808	9223372036854775807	9223372036854775806
+9223372036854775807	9223372036854775808	9223372036854775807
 select min(big),max(big),max(big)-1 from t1 group by a;
 min(big)	max(big)	max(big)-1
--9223372036854775808	9223372036854775807	9223372036854775806
+9223372036854775807	-9223372036854775808	9223372036854775807
 alter table t1 modify big bigint not null;
 select min(big),max(big),max(big)-1 from t1;
 min(big)	max(big)	max(big)-1
@@ -60,13 +63,12 @@
 min(big)	max(big)	max(big)-1
 -9223372036854775808	9223372036854775807	9223372036854775806
 insert into t1 (big) values (9223372036854775808);
+ERROR 22003: Out of range value for column 'big' at row 1
 select * from t1;
 a	big
-1	-1
 1	-9223372036854775808
 1	9223372036854775807
 1	-9223372036854775808
-1	-9223372036854775808
 select min(big),max(big),max(big)-1 from t1;
 min(big)	max(big)	max(big)-1
 -9223372036854775808	9223372036854775807	9223372036854775806
@@ -83,11 +85,9 @@
 alter table t1 modify big bigint not null;
 select * from t1;
 a	big
-1	-1
 1	-9223372036854775808
 1	9223372036854775807
 1	-9223372036854775808
-1	-9223372036854775808
 select min(big),max(big),max(big)-1 from t1;
 min(big)	max(big)	max(big)-1
 -9223372036854775808	9223372036854775807	9223372036854775806
@@ -120,12 +120,12 @@
 Warnings:
 Warning	1292	Truncated incorrect DOUBLE value: '0x8000000000000001'
 create table t1 (
-value64  bigint  not null,
+value64  bigint  unsigned not null,
 value32  integer          not null,
 primary key(value64, value32)
 );
 create table t2 (
-value64  bigint  not null,
+value64  bigint unsigned not null,
 value32  integer          not null,
 primary key(value64, value32)
 );
@@ -133,28 +133,24 @@
 insert into t1 values( 9223372036854775807, 2);
 insert into t2 values(17156792991891826145, 3);
 insert into t2 values( 9223372036854775807, 4);
-select * from t1;
+select * from t1 ORDER BY value32;
 value64	value32
 -1289951081817725471	1
 9223372036854775807	2
-select * from t2;
+select * from t2 ORDER BY value32;
 value64	value32
 -1289951081817725471	3
 9223372036854775807	4
-select * from t1, t2 where t1.value64=17156792991891826145 and
-t2.value64=17156792991891826145;
-value64	value32	value64	value32
--1289951081817725471	1	-1289951081817725471	3
-select * from t1, t2 where t1.value64=17156792991891826145 and
-t2.value64=t1.value64;
-value64	value32	value64	value32
--1289951081817725471	1	-1289951081817725471	3
-select * from t1, t2 where t1.value64= 9223372036854775807 and
-t2.value64=9223372036854775807;
+select * from t1, t2 where t1.value64=17156792991891826145 and t2.value64=17156792991891826145;
+value64	value32	value64	value32
+-1289951081817725471	1	-1289951081817725471	3
+select * from t1, t2 where t1.value64=17156792991891826145 and t2.value64=t1.value64;
+value64	value32	value64	value32
+-1289951081817725471	1	-1289951081817725471	3
+select * from t1, t2 where t1.value64= 9223372036854775807 and t2.value64=9223372036854775807;
 value64	value32	value64	value32
 9223372036854775807	2	9223372036854775807	4
-select * from t1, t2 where t1.value64= 9223372036854775807 and
-t2.value64=t1.value64;
+select * from t1, t2 where t1.value64= 9223372036854775807 and t2.value64=t1.value64;
 value64	value32	value64	value32
 9223372036854775807	2	9223372036854775807	4
 drop table t1, t2;
@@ -175,11 +171,18 @@
 show create table t1;
 Table	Create Table
 t1	CREATE TABLE `t1` (
+  `a` BIGINT UNSIGNED NOT NULL
+) ENGINE=DEFAULT COLLATE = utf8_general_ci
+drop table t1;
+create table t1 select 72036854775809 as 'a';
+show create table t1;
+Table	Create Table
+t1	CREATE TABLE `t1` (
   `a` BIGINT NOT NULL
 ) ENGINE=DEFAULT COLLATE = utf8_general_ci
 select * from t1;
 a
--9223372036854775807
+72036854775809
 drop table t1;
 DROP DATABASE IF EXISTS `scott`;
 Warnings:
@@ -192,17 +195,17 @@
 insert into t1 values (-1,-1,-1,-1);
 select * from t1;
 a	b	c	d
+-1	-1	-1	-1
 18446744073709551615	18446744073709551615	18446744073709551615	18446744073709551615
--1	-1	-1	-1
 drop table t1;
 create table t1 ( quantity decimal(2));
 insert into t1 values (50), (-50), (0), (-1);
 select * from t1;
 quantity
+-1
+-50
+0
 50
--50
-0
--1
 drop table t1;
 CREATE TABLE t1 (
 `col1` INT NULL,
@@ -321,7 +324,7 @@
 col1	col2	col3	col4	col5	col6	col7	col8	col9	col10	col11	col12	col13	col14	col15	col16	col17	col18	col19	col20	col21	col22	col23	col24	col25	col26	col27	col28	col29	col30	col31	col32	col33	col34	col35	col36	col37	col38	fix1	fix2	fix3	fix4	fix5	fix6	fix7	fix8	fix9	fix10	fix11	fix12	fix13	fix14	fix15	fix16	fix17	fix18	fix19	fix20	fix21	fix22	fix23	fix24	fix25	fix26	fix27	fix28	fix29	fix30
 9	99	999	9999	99999	999999	9999999	99999999	999999999	9999999999	99999999999	999999999999	9999999999999	99999999999999	999999999999999	9999999999999999	99999999999999999	999999999999999999	9999999999999999999	99999999999999999999	999999999999999999999	9999999999999999999999	99999999999999999999999	999999999999999999999999	9999999999999999999999999	99999999999999999999999999	999999999999999999999999999	9999999999999999999999999999	99999999999999999999999999999	999999999999999999999999999999	9999999999999999999999999999999	99999999999999999999999999999999	999999999999999999999999999999999	9999999999999999999999999999999999	99999999999999999999999999999999999	999999999999999999999999999999999999	9999999999999999999999999999999999999	99999999999999999999999999999999999999	9999999999999999999999999999999999999.9	999999999999999999999999999999999999.99	99999999999999999999999999999999999.999	9999999999999999999999999999999999.9999	999999999999999999999999999999999.99999	99999999999999999999999999999999.999999	9999999999999999999999999999999.9999999	999999999999999999999999999999.99999999	99999999999999999999999999999.999999999	9999999999999999999999999999.9999999999	999999999999999999999999999.99999999999	99999999999999999999999999.999999999999	9999999999999999999999999.9999999999999	999999999999999999999999.99999999999999	99999999999999999999999.999999999999999	9999999999999999999999.9999999999999999	999999999999999999999.99999999999999999	99999999999999999999.999999999999999999	9999999999999999999.9999999999999999999	999999999999999999.99999999999999999999	99999999999999999.999999999999999999999	9999999999999999.9999999999999999999999	999999999999999.99999999999999999999999	99999999999999.999999999999999999999999	9999999999999.9999999999999999999999999	999999999999.99999999999999999999999999	99999999999.999999999999999999999999999	9999999999.9999999999999999999999999999	999999999.99999999999999999999999999999	99999999.999999999999999999999999999999
 DROP TABLE t1;
-create table t1 (bigint_col bigint);
+create table t1 (bigint_col bigint unsigned);
 insert into t1 values (17666000000000000000);
 select * from t1 where bigint_col=17666000000000000000;
 bigint_col
@@ -334,11 +337,11 @@
 select 10000002383263201056 mod 50 as result;
 result
 6
-create table t1 (c1 bigint);
+create table t1 (c1 bigint unsigned);
 insert into t1 values (10000002383263201056);
 select c1 mod 50 as result from t1;
 result
--10
+6
 drop table t1;
 select -9223372036854775808;
 Catalog	Database	Table	Table_alias	Column	Column_alias	Type	Length	Max length	Is_null	Flags	Decimals	Charsetnr

=== modified file 'tests/r/case.result'
--- tests/r/case.result	2010-10-06 07:52:09 +0000
+++ tests/r/case.result	2010-12-20 19:20:57 +0000
@@ -194,7 +194,7 @@
 2.00	2	NULL
 DROP TABLE t1,t2;
 End of 4.1 tests
-create table t1 (a int, b bigint);
+create table t1 (a int, b bigint unsigned);
 create table t2 (c int);
 insert into t1 (a, b) values (1,4572794622775114594), (2,18196094287899841997),
 (3,11120436154190595086);

=== modified file 'tests/r/create.result'
--- tests/r/create.result	2010-12-16 02:16:37 +0000
+++ tests/r/create.result	2010-12-20 19:20:57 +0000
@@ -1470,7 +1470,7 @@
   `HOST` VARCHAR(1025) NOT NULL,
   `DB` VARCHAR(256) DEFAULT NULL,
   `COMMAND` VARCHAR(16) NOT NULL,
-  `TIME` BIGINT NOT NULL,
+  `TIME` BIGINT UNSIGNED NOT NULL,
   `STATE` VARCHAR(256) DEFAULT NULL,
   `INFO` VARCHAR(100) DEFAULT NULL,
   `HAS_GLOBAL_LOCK` VARCHAR(5) NOT NULL
@@ -1487,7 +1487,7 @@
   `HOST` VARCHAR(1025) NOT NULL,
   `DB` VARCHAR(256) DEFAULT NULL,
   `COMMAND` VARCHAR(16) NOT NULL,
-  `TIME` BIGINT NOT NULL,
+  `TIME` BIGINT UNSIGNED NOT NULL,
   `STATE` VARCHAR(256) DEFAULT NULL,
   `INFO` VARCHAR(100) DEFAULT NULL,
   `HAS_GLOBAL_LOCK` VARCHAR(5) NOT NULL

=== modified file 'tests/r/func_in.result'
--- tests/r/func_in.result	2010-12-02 04:43:38 +0000
+++ tests/r/func_in.result	2010-12-20 19:20:57 +0000
@@ -385,7 +385,7 @@
 a
 SELECT * FROM t1 WHERE a IN (-1, -2);
 a
-CREATE TABLE t2 (a BIGINT);
+CREATE TABLE t2 (a BIGINT UNSIGNED);
 insert into t2 values(13491727406643098568),
 (0x0fffffefffffffff),
 (0x0ffffffeffffffff),

=== modified file 'tests/r/range.result'
--- tests/r/range.result	2010-12-02 05:07:59 +0000
+++ tests/r/range.result	2010-12-20 19:20:57 +0000
@@ -489,7 +489,7 @@
 1025	Y	25	1025	Y	25
 1026	Z	26	1026	Z	26
 drop table t1,t2;
-create table t1 (x bigint not null);
+create table t1 (x bigint unsigned not null);
 insert into t1(x) values (0x0ffffffffffffff0);
 insert into t1(x) values (0x0ffffffffffffff1);
 select * from t1;
@@ -507,13 +507,13 @@
 0
 select count(*) from t1 where x < -16;
 count(*)
-0
+1
 select count(*) from t1 where x = -16;
 count(*)
-0
+1
 select count(*) from t1 where x > -16;
 count(*)
-2
+0
 select count(*) from t1 where x = 18446744073709551601;
 count(*)
 0
@@ -544,7 +544,7 @@
 1
 select count(*) from t2 where x = 18446744073709551601;
 count(*)
-1
+0
 drop table t1,t2;
 create table t1 (x bigint not null primary key) engine=innodb;
 insert into t1(x) values (0x0ffffffffffffff0);
@@ -575,8 +575,21 @@
 count(*)
 0
 drop table t1;
-create table t1 (a bigint);
+create table t1 (a bigint unsigned);
+show create table t1;
+Table	Create Table
+t1	CREATE TABLE `t1` (
+  `a` BIGINT UNSIGNED DEFAULT NULL
+) ENGINE=InnoDB COLLATE = utf8_general_ci
 create index t1i on t1(a);
+show create table t1;
+Table	Create Table
+t1	CREATE TABLE `t1` (
+  `a` BIGINT UNSIGNED DEFAULT NULL,
+  KEY `t1i` (`a`)
+) ENGINE=InnoDB COLLATE = utf8_general_ci
+insert into t1 values (9223372036854775807);
+truncate t1;
 insert into t1 select 18446744073709551615;
 insert into t1 select 18446744073709551614;
 explain select * from t1 where a <> -1;
@@ -584,7 +597,7 @@
 1	SIMPLE	t1	index	t1i	t1i	9	NULL	2	Using where; Using index
 select * from t1 where a <> -1;
 a
--2
+-1
 explain select * from t1 where a > -1 or a < -1;
 id	select_type	table	type	possible_keys	key	key_len	ref	rows	Extra
 1	SIMPLE	t1	index	t1i	t1i	9	NULL	2	Using where; Using index

=== modified file 'tests/r/strict.result'
--- tests/r/strict.result	2010-10-06 07:52:09 +0000
+++ tests/r/strict.result	2010-12-20 19:20:57 +0000
@@ -108,6 +108,8 @@
 Warnings:
 Warning	1264	Out of range value for column 'col1' at row 1
 INSERT IGNORE INTO t1 VALUES (9223372036854775808);
+Warnings:
+Warning	1264	Out of range value for column 'col1' at row 1
 INSERT IGNORE INTO t1 VALUES ('-9223372036854775809');
 Warnings:
 Warning	1264	Out of range value for column 'col1' at row 1

=== modified file 'tests/r/user_var.result'
--- tests/r/user_var.result	2010-12-02 05:10:00 +0000
+++ tests/r/user_var.result	2010-12-20 19:20:57 +0000
@@ -203,7 +203,7 @@
 @a
 18446744071710965857
 CREATE TABLE `bigfailure` (
-`afield` BIGINT NOT NULL
+`afield` BIGINT UNSIGNED NOT NULL
 );
 INSERT INTO `bigfailure` VALUES (18446744071710965857);
 SELECT * FROM bigfailure;
@@ -226,15 +226,15 @@
 SET @a := (SELECT afield FROM bigfailure);
 SELECT @a;
 @a
--1998585759
+18446744071710965857
 SET @a := (select afield from (SELECT afield FROM bigfailure) as b);
 SELECT @a;
 @a
--1998585759
+18446744071710965857
 SET @a := (select * from bigfailure where afield = (SELECT afield FROM bigfailure));
 SELECT @a;
 @a
--1998585759
+18446744071710965857
 drop table bigfailure;
 create table t1(f1 int, f2 int);
 insert into t1 values (1,2),(2,3),(3,1);

=== modified file 'tests/t/bigint.test'
--- tests/t/bigint.test	2010-04-05 23:46:43 +0000
+++ tests/t/bigint.test	2010-12-20 19:20:57 +0000
@@ -23,7 +23,7 @@
 # This will work on 4.0 as we then have internal handling of bigint variables.
 #
 
-create table t1 (a bigint not null, primary key(a));
+create table t1 (a bigint unsigned not null, primary key(a));
 insert into t1 values (9223372036854775808);
 insert into t1 values (0x7000000000000000);
 select * from t1;
@@ -33,14 +33,19 @@
 select * from t1;
 drop table t1;
 
-create table t1 ( a int not null default 1, big bigint );
+create table t1 ( a int not null default 1, big bigint unsigned);
+--error ER_WARN_DATA_OUT_OF_RANGE
 insert into t1 (big) values (-1),(9223372036854775808),(9223372036854775807),(9223372036854775808);
+--error ER_WARN_DATA_OUT_OF_RANGE
+insert into t1 (big) values (-1);
+insert into t1 (big) values (9223372036854775808),(9223372036854775807),(9223372036854775808);
 select * from t1;
 select min(big),max(big),max(big)-1 from t1;
 select min(big),max(big),max(big)-1 from t1 group by a;
 alter table t1 modify big bigint not null;
 select min(big),max(big),max(big)-1 from t1;
 select min(big),max(big),max(big)-1 from t1 group by a;
+--error ER_WARN_DATA_OUT_OF_RANGE
 insert into t1 (big) values (9223372036854775808);
 select * from t1;
 select min(big),max(big),max(big)-1 from t1;
@@ -82,13 +87,13 @@
 
 # Test for BUG#8562: joins over BIGINT value + constant propagation
 create table t1 (
- value64  bigint  not null,
+ value64  bigint  unsigned not null,
  value32  integer          not null,
  primary key(value64, value32)
 );
 
 create table t2 (
- value64  bigint  not null,
+ value64  bigint unsigned not null,
  value32  integer          not null,
  primary key(value64, value32)
 );
@@ -98,18 +103,18 @@
 insert into t2 values(17156792991891826145, 3);
 insert into t2 values( 9223372036854775807, 4);
 
-select * from t1;
-select * from t2;
-
-select * from t1, t2 where t1.value64=17156792991891826145 and
-t2.value64=17156792991891826145;
-select * from t1, t2 where t1.value64=17156792991891826145 and
-t2.value64=t1.value64;
-
-select * from t1, t2 where t1.value64= 9223372036854775807 and
-t2.value64=9223372036854775807;
-select * from t1, t2 where t1.value64= 9223372036854775807 and
-t2.value64=t1.value64;
+select * from t1 ORDER BY value32;
+select * from t2 ORDER BY value32;
+
+--sorted_result
+select * from t1, t2 where t1.value64=17156792991891826145 and t2.value64=17156792991891826145;
+--sorted_result
+select * from t1, t2 where t1.value64=17156792991891826145 and t2.value64=t1.value64;
+
+--sorted_result
+select * from t1, t2 where t1.value64= 9223372036854775807 and t2.value64=9223372036854775807;
+--sorted_result
+select * from t1, t2 where t1.value64= 9223372036854775807 and t2.value64=t1.value64;
 
 drop table t1, t2;
 
@@ -132,11 +137,18 @@
 --replace_regex /ENGINE=[a-zA-Z]+/ENGINE=DEFAULT/
 show create table t1;
 drop table t1;
+
 create table t1 select 9223372036854775809 as 'a';
 --replace_regex /ENGINE=[a-zA-Z]+/ENGINE=DEFAULT/
 show create table t1;
+drop table t1;
+
+create table t1 select 72036854775809 as 'a';
+--replace_regex /ENGINE=[a-zA-Z]+/ENGINE=DEFAULT/
+show create table t1;
 select * from t1;
 drop table t1;
+
 DROP DATABASE IF EXISTS `scott`;
 
 
@@ -151,11 +163,13 @@
 );
 
 insert into t1 values (-1,-1,-1,-1);
+--sorted_result
 select * from t1;
 drop table t1;
 
 create table t1 ( quantity decimal(2));
 insert into t1 values (50), (-50), (0), (-1);
+--sorted_result
 select * from t1;
 drop table t1;
 
@@ -279,11 +293,12 @@
 999999999.99999999999999999999999999999,
 99999999.999999999999999999999999999999);
 
+--sorted_result
 SELECT * FROM t1;
 DROP TABLE t1;
 
 #bug #9088 BIGINT WHERE CLAUSE
-create table t1 (bigint_col bigint);
+create table t1 (bigint_col bigint unsigned);
 insert into t1 values (17666000000000000000);
 select * from t1 where bigint_col=17666000000000000000;
 select * from t1 where bigint_col='17666000000000000000';
@@ -294,7 +309,7 @@
 
 select 10000002383263201056 mod 50 as result;
 
-create table t1 (c1 bigint);
+create table t1 (c1 bigint unsigned);
 insert into t1 values (10000002383263201056);
 select c1 mod 50 as result from t1;
 drop table t1;

=== modified file 'tests/t/case.test'
--- tests/t/case.test	2010-10-06 07:52:09 +0000
+++ tests/t/case.test	2010-12-20 19:20:57 +0000
@@ -161,7 +161,7 @@
 #
 # #30782: Truncated BIGINT columns 
 #
-create table t1 (a int, b bigint);
+create table t1 (a int, b bigint unsigned);
 create table t2 (c int);
 insert into t1 (a, b) values (1,4572794622775114594), (2,18196094287899841997),
   (3,11120436154190595086);

=== modified file 'tests/t/func_in.test'
--- tests/t/func_in.test	2010-10-06 07:52:09 +0000
+++ tests/t/func_in.test	2010-12-20 19:20:57 +0000
@@ -295,7 +295,7 @@
 SELECT * FROM t1 WHERE a=-1 OR a=-2 ;
 SELECT * FROM t1 WHERE a IN (-1, -2);
 
-CREATE TABLE t2 (a BIGINT);
+CREATE TABLE t2 (a BIGINT UNSIGNED);
 insert into t2 values(13491727406643098568),
        (0x0fffffefffffffff),
        (0x0ffffffeffffffff),

=== modified file 'tests/t/range.test'
--- tests/t/range.test	2010-08-21 22:42:44 +0000
+++ tests/t/range.test	2010-12-20 19:20:57 +0000
@@ -395,7 +395,7 @@
 
 # Fix for bug#4488 
 #
-create table t1 (x bigint not null);
+create table t1 (x bigint unsigned not null);
 insert into t1(x) values (0x0ffffffffffffff0);
 insert into t1(x) values (0x0ffffffffffffff1);
 select * from t1;
@@ -440,8 +440,12 @@
 #
 # Bug #11185 incorrect comparison of int to signed constant
 #
-create table t1 (a bigint);
+create table t1 (a bigint unsigned);
+show create table t1;
 create index t1i on t1(a);
+show create table t1;
+insert into t1 values (9223372036854775807);
+truncate t1;
 insert into t1 select 18446744073709551615;
 insert into t1 select 18446744073709551614;
 

=== modified file 'tests/t/user_var.test'
--- tests/t/user_var.test	2010-08-26 21:56:15 +0000
+++ tests/t/user_var.test	2010-12-20 19:20:57 +0000
@@ -155,7 +155,7 @@
 # Second part, set user var from large number in table
 # then select it
 CREATE TABLE `bigfailure` (
-  `afield` BIGINT NOT NULL
+  `afield` BIGINT UNSIGNED NOT NULL
 );
 INSERT INTO `bigfailure` VALUES (18446744071710965857);
 SELECT * FROM bigfailure;

